C********** ZENITH ANGLE, DAY OF YEAR, TIME ***********************
C******************************************************************
C
C
        subroutine socoxhio (ld,t,FLAT,Elon,height,
     &          DECLIN, ZENITH, xhio, SUNRSE, SUNSET)
c--------------------------------------------------------------------
c       s/r to calculate the solar declination, zenith angle, and
c       sunrise & sunset times  - based on Newbern Smith's algorithm
c       [leo mcnamara, 1-sep-86, last modified 16-jun-87]
c       {dieter bilitza, 30-oct-89, modified for IRI application}
c
c in:   ld      local day of year
c       t       local hour (decimal)
c       flat    northern latitude in degrees
c       elon    east longitude in degrees
c		height	height in km
c
c out:  declin      declination of the sun in degrees
c       zenith      zenith angle of the sun in degrees
c       sunrse      local time of sunrise in hours 
c       sunset      local time of sunset in hours 
c-------------------------------------------------------------------
c
C        common/const/dtr,pi     /const1/humr,dumr
c amplitudes of Fourier coefficients  --  1955 epoch.................
        data    p1,p2,p3,p4,p6 /
     &  0.017203534,0.034407068,0.051610602,0.068814136,0.103221204 /
	data REo/6356.77/
c
c s/r is formulated in terms of WEST longitude.......................
        wlon = 360. - Elon
c
        	pi=ATAN(1.0)*4.
        	dtr=pi/180.
        	humr=pi/12.
        	dumr=pi/182.5

	anglS = acos(Reo/(height+Reo))
	xhio = (90.0 + 16.0/60.0)*dtr + anglS

c time of equinox for 1980...........................................
        td = ld + (t + Wlon/15.) / 24.
        te = td + 0.9369
c
c declination of the sun..............................................
        dcl = 23.256 * sin(p1*(te-82.242)) + 0.381 * sin(p2*(te-44.855))
     &      + 0.167 * sin(p3*(te-23.355)) - 0.013 * sin(p4*(te+11.97))
     &      + 0.011 * sin(p6*(te-10.41)) + 0.339137
Cpre        DECLIN = dcl
CPP+
       wo=2.0*pi/365.0											 !PP
       sdecl=0.39795*sin(wo*(ld-82)+(1.9*pi/180.0)*sin(wo*(ld-3))) !PP
	dc=asin(sdecl)											 !PP
        dcl = dc / dtr
	DECLIN = dcl
CPP+
c the equation of time................................................
        tf = te - 0.5
        eqt = -7.38*sin(p1*(tf-4.)) - 9.87*sin(p2*(tf+9.))
     &      + 0.27*sin(p3*(tf-53.)) - 0.2*cos(p4*(tf-17.))
        et = eqt * dtr / 4.
c
Cpre        fa = flat * dtr !pre
        phi = humr * ( t - 12.) + et   ! time Srad   _pre
CPP+
       w=2.0*pi*(ld-1)/365.0       !PP
	ew=7.35*sin(w)-0.385*cos(w)+3.52*cos(2.0*w)+9.41*sin(2.0*w)  !PP
	phi=pi*(t-12.0-ew)/12.0 !time Srad PP  new
c
Cpre        a = sin(fa) * sin(dc)	!pre
Cpre        b = cos(fa) * cos(dc)	!pre
Cpre        	cosx = a + b * cos(phi)	!pre
Cpre        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx) !pre
Cpre        zenith = acos(cosx) / dtr				  !pre
CPP
C NEWWWWWWWWWWWWWWWWWWWWWW
C at SR & SS: cos(phi)=-tg(flat*umr)*tg(dc)        
C tg(flat*umr)=-cos(phi)/tg(dc)
        tdc=sin(dc)/cos(dc)
         flatumr=atan(-cos(phi)/tdc)
	flat0=flatumr/dtr  ! glat(height=0.)
	iglat0=nint(flat0)
	cxhio=cos(xhio*dtr)
      dcosmin=cxhio
	GOTO 123 !TEMPPPPPPPPPPPPPP
C
        if (iglat0.gt.0) then
	iglat2=90
	istep=1
	               else
	iglat2=-90
	istep=-1
	endif
C++
CTEMPP	glat=flat0
123   glat=-90.0
       iglat0=1
	iglat2=180
	istep=1
	do ilat=iglat0,iglat2,istep
	glat=glat+istep
        fa = glat * dtr
c
        a = sin(fa) * sin(dc)
        b = cos(fa) * cos(dc)
        	cosx = a + b * cos(phi)
        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx)
         if (abs(cosx-dcosmin).lt.0.01) then
	   flat=glat
	   dcosmin=cosx
	   endif
	enddo    
C
        fa = flat * dtr !pre
        a = sin(fa) * sin(dc)	!pre
        b = cos(fa) * cos(dc)	!pre
        	cosx = a + b * cos(phi)	!pre
        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx) !pre
        zenith = acos(cosx) / dtr				  !pre
C
	RETURN
c
c calculate sunrise and sunset times --  at the ground...........
c see Explanatory Supplement to the Ephemeris (1961) pg 401......
c sunrise at height h metres is at...............................
		h=height*1000.
        chih = 90.83 + 0.0347 * sqrt(h)
c this includes corrections for horizontal refraction and........
c semi-diameter of the solar disk................................
        ch = cos(chih * dtr)
        cosphi = (ch -a ) / b
c if abs(secphi) > 1., sun does not rise/set.....................
c allow for sun never setting - high latitude summer.............
        secphi = 999999.
        if(cosphi.ne.0.) secphi = 1./cosphi
        sunset = 99.
        sunrse = 99.
        if(secphi.gt.-1.0.and.secphi.le.0.) return
c allow for sun never rising - high latitude winter..............
        sunset = -99.
        sunrse = -99.
        if(secphi.gt.0.0.and.secphi.lt.1.) return
c
        	cosx = cosphi
        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx)
        phi = acos(cosx)
        et = et / humr
        phi = phi / humr
        sunrse = 12. - phi - et
        sunset = 12. + phi - et
        if(sunrse.lt.0.) sunrse = sunrse + 24.
        if(sunset.ge.24.) sunset = sunset - 24.
c special case sunrse > sunset
        if(sunrse.gt.sunset) then
        	sunx=sign(99.0,flat)
        	if(ld.gt.91.and.ld.lt.273) then
        		sunset = sunx
        		sunrse = sunx
        	else
        		sunset = -sunx
        		sunrse = -sunx
        	endif
        	endif
c
        return
        end
c
