C********** ZENITH ANGLE, DAY OF YEAR, TIME ***********************
C******************************************************************
C
C
        subroutine socoxhio (ld,t,FLAT,Elon,height,
     &          DECLIN, ZENITH, xhiograd, SUNRSE, SUNSET)
c--------------------------------------------------------------------
c       s/r to calculate the solar declination, zenith angle, and
c       sunrise & sunset times  - based on Newbern Smith's algorithm
c       [leo mcnamara, 1-sep-86, last modified 16-jun-87]
c       {dieter bilitza, 30-oct-89, modified for IRI application}
c
c in:   ld      local day of year
c       t       local hour (decimal)
c       flat    northern latitude in degrees
c       elon    east longitude in degrees
c		height	height in km
c
c out:  declin      declination of the sun in degrees
c       zenith      zenith angle of the sun in degrees
c       sunrse      local time of sunrise in hours 
c       sunset      local time of sunset in hours 
c-------------------------------------------------------------------
c
C        common/const/dtr,pi     /const1/humr,dumr
c amplitudes of Fourier coefficients  --  1955 epoch.................
        data    p1,p2,p3,p4,p6 /
     &  0.017203534,0.034407068,0.051610602,0.068814136,0.103221204 /
	data REo/6356.77/
c
c s/r is formulated in terms of WEST longitude.......................
        wlon = 360. - Elon
c
        	pi=ATAN(1.0)*4.
        	dtr=pi/180.
        	humr=pi/12.
        	dumr=pi/182.5

	anglS = acos(Reo/(height+Reo))
	xhio = (90.0 + 16.0/60.0)*dtr + anglS	 !rad
	xhiograd=xhio/dtr

c time of equinox for 1980...........................................
        td = ld + (t + Wlon/15.) / 24.
        te = td + 0.9369
c
c declination of the sun..............................................
        dcl = 23.256 * sin(p1*(te-82.242)) + 0.381 * sin(p2*(te-44.855))
     &      + 0.167 * sin(p3*(te-23.355)) - 0.013 * sin(p4*(te+11.97))
     &      + 0.011 * sin(p6*(te-10.41)) + 0.339137
	  dc=dcl * dtr
        DECLIN = dcl
CPP+
C++       wo=2.0*pi/365.0											 !PP
c++       sdecl=0.39795*sin(wo*(ld-82)+(1.9*pi/180.0)*sin(wo*(ld-3))) !PP
c++	dc=asin(sdecl)											 !PP
c++        dcl = dc / dtr
c++	DECLIN = dcl
CPP+
c the equation of time................................................
        tf = te - 0.5
        eqt = -7.38*sin(p1*(tf-4.)) - 9.87*sin(p2*(tf+9.))
     &      + 0.27*sin(p3*(tf-53.)) - 0.2*cos(p4*(tf-17.))
        et = eqt * dtr / 4.
c
        fa = flat * dtr !pre
        phi = humr * ( t- 12.) + et   ! time Srad   _pre
	phigrad=phi/dtr
CPP+
C-       w=2.0*pi*(ld-1)/365.0       !PP
C-	ew=7.35*sin(w)-0.385*cos(w)+3.52*cos(2.0*w)+9.41*sin(2.0*w)  !PP
C-	phi=pi*(t-12.0-ew)/12.0 !time Srad PP  new
c
C_        a = sin(fa) * sin(dc)	!pre
C_        b = cos(fa) * cos(dc)	!pre
C_        	cosx = a + b * cos(phi)	!pre
C_        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx) !pre
C_        zenith = acos(cosx) / dtr				  !pre
CPP
C NEWWWWWWWWWWWWWWWWWWWWWW
C at SR & SS: cos(phi)=-tg(flat*umr)*tg(dc)        
C tg(flat*umr)=-cos(phi)/tg(dc)
c++        tdc=sin(dc)/cos(dc)
c++         flatumr=atan(-cos(phi)/tdc)
c++	flat0=flatumr/dtr  ! glat (height=0.)
c++	iglat0=nint(flat0)
c++	cxhio=cos(xhio)  !COMPARE
c++      dcosmin=cxhio
c++	sflat0=sin(flat0*dtr)
c++      cflat0=cos(flat0*dtr)
C++++++++++
c++       rat=cos(flatumr-dc)/cos(flatumr+dc)
c++	 tphi=2.0*atan(sqrt(rat)) !rad
c++        tphigrad=tphi/dtr
C-	flat=flat0
C-	 RETURN
CP_	GOTO 123 !TEMPPPPPPPPPPPPPP
C
C_        if (iglat0.gt.0) then
C_	iglat2=90
C_	istep=1
C_	               else
C_	iglat2=-90
C_	istep=-1
C_	endif
C++
C_	glat=flat0
CP_123   glat=-90.0
c++       iglat0=-90
c++	iglat2=90
c++	istep=1
c++	do ilat=iglat0,iglat2,istep
C	glat=glat+istep
c++       glat=float(ilat)
c++        fa = glat * dtr
c
C+        a = sin(fa) * sin(dc)
C+        b = cos(fa) * cos(dc)
c++              a = sin(fa)
c++        b = cos(fa)
C++        	cosx = a + b * cos(phi)
c++      dcosxhi=sin(dc)*(a-sflat0)+cos(dc)*cos(phi)*(b-cflat0)
C-        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx)
C+        if (abs(cosx-dcosmin).lt.0.001) then
c++        if (abs(dcosxhi-dcosmin).lt.0.001) then
C_         if (cosx.gt.dcosmin) then
c++	   flat=glat
C-	   dcosmin=cosx
c++	   dcosmin=dcosxhi
c++	   endif
c++	enddo    
C
        fa = flat * dtr !pre
        a = sin(fa) * sin(dc)	!pre
        b = cos(fa) * cos(dc)	!pre
        	cosx = a + b * cos(phi)	!pre
        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx) !pre
        zenith = acos(cosx) / dtr				  !pre
C
C_	RETURN
c
c calculate sunrise and sunset times --  at the ground...........
c see Explanatory Supplement to the Ephemeris (1961) pg 401......
c sunrise at height h metres is at...............................
		h=height*1000.
        chih = 90.83 + 0.0347 * sqrt(h)
c this includes corrections for horizontal refraction and........
c semi-diameter of the solar disk................................
        ch = cos(chih * dtr)
        cosphi = (ch -a ) / b
c if abs(secphi) > 1., sun does not rise/set.....................
c allow for sun never setting - high latitude summer.............
        secphi = 999999.
        if(cosphi.ne.0.) secphi = 1./cosphi
        sunset = 99.
        sunrse = 99.
        if(secphi.gt.-1.0.and.secphi.le.0.) return
c allow for sun never rising - high latitude winter..............
        sunset = -99.
        sunrse = -99.
        if(secphi.gt.0.0.and.secphi.lt.1.) return
c
        	cosx = cosphi
        	if(abs(cosx).gt.1.) cosx=sign(1.,cosx)
        phi = acos(cosx)
        et = et / humr
        phi = phi / humr
        sunrse = 12. - phi - et
        sunset = 12. + phi - et
        if(sunrse.lt.0.) sunrse = sunrse + 24.
        if(sunset.ge.24.) sunset = sunset - 24.
c special case sunrse > sunset
        if(sunrse.gt.sunset) then
        	sunx=sign(99.0,flat)
        	if(ld.gt.91.and.ld.lt.273) then
        		sunset = sunx
        		sunrse = sunx
        	else
        		sunset = -sunx
        		sunrse = -sunx
        	endif
        	endif
c
        return
        end
c
