      subroutine subrewindex(tecx,xmed,iwx)
C.............................................................June 2021
C
C   Procedure to produce Proxy TECx from the ionospheric weather Wx index
C
C   Input: xtecx = TECi  - instantaneous proxy value of total electron content
C    		 xmed = GTEC median - quiet reference (median) value of total electron content
C   
C   Output: TECX
C   Input:
C           Wx = 0, +1 or -1 (quiet state)
C           Wx = +2 or -2 (moderate disturbance)
C           Wx = +3 or -3 (moderate storm)
C           Wx = +4 or -4 (intense storm)
C
C   Includes logarithmic scale indices -4,-3,-2,-1,0,1,2,3,4
C   according to thresholds of 
C           log10(xpar/xmed)=-0.477,-0.301,-0.155,-0.045,0,0.045,0.155,0.301,0.477  
C
	      DIMENSION TR(9),RAT(9)
 	INTEGER IIN(9)
   		data IIN/-4,-3,-2,-1,0,1,2,3,4/           ! W-index
	data TR/-0.477,-.301,-.155,-.045,0.0		  ! ln(Wx/Wmed)
	+,.045,.155,.301,0.477/
	data RAT/0.5,0.59,0.79,0.95,1.0		  ! rat=TECx/TECmed
	+,1.05,1.26,1.69,2.0/
c=	data RAT/0.3,0.5,0.7,0.9,1.0		  ! rat=TECx/TECmed
c=	+,1.1,1.5,2.0,3.0/
C  Temp:
c    	 if (delog.ne.0.) goto 5   ! temp if delog is entered
C
	do 1 n=1,9
	thesh=TR(n)
	if (iwx.eq.iin(n)) then
	tecx=rat(n)*xmed              ! W-index
	exit
	endif
   1	continue
C
C
	RETURN
	END
C
C
C ===============================================================
